--[[
  logtest.lua
  
  This is an example script showing usage of log.lua library.
--]]

require "log"
require "dummy"

-- log1 is automatically named and opened for append by default:
log1=log.open()
log1:print("Line 1, this text should be in file ",log1.name)
log1:print("Line 2.")

-- log2 is named my_log.txt and overwritten on open.
-- Avoid special characters (anything other than a-z A-Z 0-9 _) in file names!
log2=log.open("my_log.txt","w")
log2:print("Full path and name of this file is ", log2.path..log2.name)

-- log1 is still open, we can write to it:
log1:print("Line 3.")

-- log:print() always appends the given string with a newline because that 
-- makes usage more convenient. When you don't want newlines, you can use 
-- io.write() directly.
--
-- Note that we must check the handle before calling write(), because 
-- if there is a problem with log.open() for instance because CHDK/LOGS
-- directory does not exist or because io functionality hasn't been ported
-- to some camera model yet, it will use print_screen instead of io.
-- In this case the handle will be nil and log2.logtype=="print_screen":
if log2.handle ~= nil then 
  log2.handle:write("Line ") 
end
log2:print("2 of log2")

log1:close()
log2:close()

-- log.open() uses an unused file name autofinder which can be used from other 
-- scripts just as well. The header should be 5 characters maximum and 
-- extension 3 chars max as all cameras don't support long filenames. 
-- Avoid special characters (anything other than a-z A-Z 0-9 _).
filename=log.find_new_filename("lua_","txt")
sleep(1000)
print("Lowest free lua_???.txt filename is ",filename)

